close all; clear variables;
%% Initialisation %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Control Varaibles
n = 10^4; T = 1*10^6; nSample = 10^3; peas = [0.7 0.999]; nA = 3;

props = {{'x'   'single_value' [0 1];  %Uniform Agents
          'sig' 'single_value' 0.2}
          
         {'x'   'single_value' {[0 1] 0}  [nA 1]; %One sided bias
          'sig' 'single_value' {0.2   0.14} [nA 1]}
          
         {'x'   'single_value' {[0 1] 1 0} [nA 1/2 1/2]; %two sided bias
          'sig' 'single_value' {0.2   0.14}    [nA 1]}};   
      
      

       
%% Normal variables
sample = randperm(n,nSample);

NetworkModel = @(agents,T,interFunc) PairOffNet(agents,T,interFunc,1);

[peasGrid,propsGrid] = meshgrid(peas,props);

Data = cell(size(peasGrid));

OpinionGraphs = cell(size(peasGrid));




%% Script Body %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
parfor sim = 1:numel(peasGrid)
    InterFunc = @(agenti,agentj) BayesInterFixedP(agenti,agentj,peasGrid(sim));   
    
    [t,data] = AgentModelerV2(n,propsGrid{sim},T,NetworkModel,InterFunc,'identify',false,'t_spacing',10^4/2)
    
    OpinionGraphs{sim} = PlotOpinions(data{1},t,{'b'});
    
    Data{sim} = data;
    
    disp([ 'Simulation ' int2str(sim) ' done'])
end
%% Saving figures %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
simType = {'CompleteUniform' 'OneSideExtreme' 'TwoSideExtreme'};


for pIdx = 1:length(peas)
    for propIdx = 1:length(simType)
        saveas(OpinionGraphs{propIdx,pIdx}, strcat(pwd,'\Figures\P', int2str(peas(pIdx)*1000), simType{propIdx},'.fig'))
    end
end